@@ -1,5 +1,3 @@
-
-#include <gtk/gtk.h>
 #include <config.h>
 
 #include <string.h>
@@ -161,21 +159,6 @@ window_theme_selection_changed (GtkTreeSelection *selection,
   g_free (window_theme_name);
 }
 
-static void
-gnome_theme_installer_run_cb (GtkWidget *button,
-			      GtkWidget *parent_window)
-{
-  gnome_theme_installer_run (parent_window, NULL, FALSE);
-}
-
-
-static void
-gnome_icon_theme_installer_run_cb (GtkWidget *button,
-			      GtkWidget *parent_window)
-{
-  gnome_theme_installer_run (parent_window, NULL, TRUE);
-}
-
 static void
 icon_theme_selection_changed (GtkTreeSelection *selection,
 			     gpointer          data)
@@ -286,7 +269,6 @@ update_gconf_key_from_selection (GtkTreeSelection *selection,
 void
 gnome_theme_details_init (void)
 {
-  GConfClient *client;
   GtkWidget *parent, *widget;
   GnomeWindowManager *window_manager;
   GladeXML *dialog;
@@ -296,7 +278,6 @@ gnome_theme_details_init (void)
   theme_details_initted = TRUE;
 
   dialog = gnome_theme_manager_get_theme_dialog ();
-  client = gconf_client_get_default ();
   window_manager = gnome_wm_manager_get_current (gdk_display_get_default_screen (gdk_display_get_default ()));
   parent = WID ("theme_details_dialog");
 
@@ -311,20 +292,14 @@ gnome_theme_details_init (void)
 		   dialog);
 
   /* gtk themes */
-  widget = WID ("control_install_button");
-  g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run_cb), parent);
   widget = WID ("control_manage_button");
   g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_manager_show_manage_themes), dialog);
 
   /* window manager themes */
-  widget = WID ("window_install_button");
-  g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_installer_run_cb), parent);
   widget = WID ("window_manage_button");
   g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_manager_window_show_manage_themes), dialog);
 
   /* icon themes */
-  widget = WID ("icon_install_button");
-  g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_icon_theme_installer_run_cb), parent);
   widget = WID ("icon_manage_button");
   g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gnome_theme_manager_icon_show_manage_themes), dialog);
 
@@ -588,5 +563,6 @@ gnome_theme_details_update_from_gconf (void)
   tree_view = WID ("icon_theme_treeview");
   theme = gconf_client_get_string (client, ICON_THEME_KEY, NULL);
   update_list_something (tree_view, theme);
+  g_object_unref (client);
   g_free (theme);
 }
